@@ -7,5 +7,8 @@ pub enum Commands {
         /// sequentially one by one crawl pages
         #[clap(short, long)]
         sync: bool,
+        /// stdout all links crawled
+        #[clap(short, long)]
+        output_links: bool,
     },
 }
